@@ -20,7 +20,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: DisplayState.py 16160 2010-11-08 15:50:51Z nick-h $
+# $Id: DisplayState.py 18655 2011-12-25 09:29:24Z m_d_n $
 
 #-------------------------------------------------------------------------
 #
@@ -481,6 +481,11 @@ class DisplayState(gen.utils.Callback):
             return self.disprel_old
 
         active = dbstate.db.get_person_from_handle(active_handle)
+        if active is None:
+            # During merger this method can be called at a time when treemodel
+            # and database are not in sync, resulting in active_handle != None,
+            # but active == None; see bug 5290 for the details.
+            return u''
         name = self.relationship.get_one_relationship(
                                             dbstate.db, default_person, active)
         #store present call data
