@@ -19,7 +19,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: _SidebarFilter.py 17538 2011-05-19 20:38:03Z m_d_n $
+# $Id: _SidebarFilter.py 18586 2011-12-12 18:38:43Z m_d_n $
 
 from gen.ggettext import gettext as _
 from bisect import insort_left
@@ -118,7 +118,7 @@ class SidebarFilter(DbGUIElement):
             widget.set_tooltip_text(tooltip)
 
     def key_press(self, obj, event):
-        if not event.state or event.state in (gtk.gdk.MOD2_MASK,):
+        if not (event.state & gtk.gdk.CONTROL_MASK):
             if event.keyval in (_RETURN, _KP_ENTER):
                 self.clicked(obj)
         return False
