@@ -165,11 +165,13 @@ class MergeEvents(ManagedWindow.ManagedWindow):
         if use_handle1:
             phoenix = self.ev1
             titanic = self.ev2
-            unselect_path = (1,)
         else:
             phoenix = self.ev2
             titanic = self.ev1
-            unselect_path = (0,)
+            # Add second handle to history so that when merge is complete, 
+            # phoenix is the selected row.
+            self.uistate.viewmanager.active_page.get_history().push(
+                    phoenix.get_handle())
 
         if self.get_widget("type_btn1").get_active() ^ use_handle1:
             phoenix.set_type(titanic.get_type())
@@ -185,9 +187,6 @@ class MergeEvents(ManagedWindow.ManagedWindow):
         
         query = MergeEventQuery(self.dbstate, phoenix, titanic)
         query.execute()
-        if self.uistate.viewmanager.active_page.selection:
-            self.uistate.viewmanager.active_page.selection.unselect_path(
-                    unselect_path)
         self.uistate.set_busy_cursor(False)
         self.close()
 
