@@ -158,11 +158,13 @@ class MergeNotes(ManagedWindow.ManagedWindow):
         if use_handle1:
             phoenix = self.no1
             titanic = self.no2
-            unselect_path = (1,)
         else:
             phoenix = self.no2
             titanic = self.no1
-            unselect_path = (0,)
+            # Add second handle to history so that when merge is complete, 
+            # phoenix is the selected row.
+            self.uistate.viewmanager.active_page.get_history().push(
+                    phoenix.get_handle())
 
         if self.get_widget("text_btn1").get_active() ^ use_handle1:
             phoenix.set_styledtext(titanic.get_styledtext())
@@ -175,9 +177,6 @@ class MergeNotes(ManagedWindow.ManagedWindow):
 
         query = MergeNoteQuery(self.dbstate, phoenix, titanic)
         query.execute()
-        if self.uistate.viewmanager.active_page.selection:
-            self.uistate.viewmanager.active_page.selection.unselect_path(
-                    unselect_path)
         self.close()
 
 #-------------------------------------------------------------------------
