@@ -196,10 +196,15 @@ class MergePeople(ManagedWindow.ManagedWindow):
             self.add(tobj, title, _("Events"))
             for event_ref in person.get_event_ref_list():
                 event_handle = event_ref.ref
+                role = event_ref.get_role()
                 name = str(
                     self.database.get_event_from_handle(event_handle).get_type())
-                self.add(tobj, normal, "%s:\t%s" % 
-                            (name, self.get_event_info(event_handle)))
+                if role.is_primary():
+                    self.add(tobj, normal, "%s:\t%s" % 
+                                (name, self.get_event_info(event_handle)))
+                else:
+                    self.add(tobj, normal, "%s (%s):\t%s" % 
+                                (name, role, self.get_event_info(event_handle)))
         plist = person.get_parent_family_handle_list()
 
         if len(plist) > 0:
@@ -303,11 +308,13 @@ class MergePeople(ManagedWindow.ManagedWindow):
         if use_handle1:
             phoenix = self.pr1
             titanic = self.pr2
-            unselect_path = (1,)
         else:
             phoenix = self.pr2
             titanic = self.pr1
-            unselect_path = (0,)
+            # Add second handle to history so that when merge is complete, 
+            # phoenix is the selected row.
+            self.uistate.viewmanager.active_page.get_history().push(
+                    phoenix.get_handle())
 
         if self.get_widget("name_btn1").get_active() ^ use_handle1:
             swapname = phoenix.get_primary_name()
@@ -325,9 +332,6 @@ class MergePeople(ManagedWindow.ManagedWindow):
             query.execute()
         except MergeError, err:
             ErrorDialog( _("Cannot merge people"), str(err))
-        if self.uistate.viewmanager.active_page.selection:
-            self.uistate.viewmanager.active_page.selection.unselect_path(
-                    unselect_path)
         self.uistate.set_busy_cursor(False)
         self.close()
         if self.update:
