@@ -169,11 +169,14 @@ class MergePlaces(ManagedWindow.ManagedWindow):
         if use_handle1:
             phoenix = self.pl1
             titanic = self.pl2
-            unselect_path = (1,)
         else:
             phoenix = self.pl2
             titanic = self.pl1
-            unselect_path = (0,)
+            # Add second handle to history so that when merge is complete, 
+            # phoenix is the selected row.
+            self.uistate.viewmanager.active_page.get_history().push(
+                    phoenix.get_handle())
+
 
         if self.get_widget("title_btn1").get_active() ^ use_handle1:
             phoenix.set_title(titanic.get_title())
@@ -190,9 +193,6 @@ class MergePlaces(ManagedWindow.ManagedWindow):
 
         query = MergePlaceQuery(self.dbstate, phoenix, titanic)
         query.execute()
-        if self.uistate.viewmanager.active_page.selection:
-            self.uistate.viewmanager.active_page.selection.unselect_path(
-                    unselect_path)
         self.uistate.set_busy_cursor(False)
         self.close()
 
