@@ -18,7 +18,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: Sort.py 14073 2010-01-14 04:21:31Z pez4brian $
+# $Id: Sort.py 18831 2012-02-06 20:44:30Z gburto01 $
 
 """
 Provide sorting routines for use in GRAMPS. Since these functions are
@@ -158,14 +158,16 @@ class Sort(object):
             return 0
         a_obj = self.database.get_event_from_handle(a_id)
         b_obj = self.database.get_event_from_handle(b_id)
-        return cmp(a_obj.get_date_object(), b_obj.get_date_object())
+        dsv1 = a_obj.get_date_object().get_sort_value()
+        dsv2 = b_obj.get_date_object().get_sort_value()
+        return cmp(dsv1, dsv2)
 
     def by_date_key(self, a_id):
         """Sort routine for comparing two events by their dates. """
         if not a_id:
             return 0
         a_obj = self.database.get_event_from_handle(a_id)
-        return a_obj.get_date_object()
+        return a_obj.get_date_object().get_sort_value()
 
     def by_place_title(self, a_id, b_id):
         """Sort routine for comparing two places. """
@@ -205,7 +207,7 @@ class Sort(object):
         evt_a = self.database.get_event_from_handle(a_id)
         plc_a = self.database.get_place_from_handle(evt_a.get_place_handle())
         plc_a_title = plc_a.title if plc_a else ""
-        return locale.strxfrml(plc_a_title)
+        return locale.strxfrm(plc_a_title)
 
     def by_event_description(self, a_id, b_id):
         """Sort routine for comparing two events by their descriptions. """
@@ -232,7 +234,7 @@ class Sort(object):
 
     def by_event_id_key(self, a_id):
         """Sort routine for comparing two events by their ID. """
-        if not (a_id and b_id):
+        if not a_id:
             return 0
         evt_a = self.database.get_event_from_handle(a_id)
         return locale.strxfrm(evt_a.get_gramps_id())
