@@ -20,7 +20,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: dbman.py 16631 2011-02-16 18:38:01Z m_d_n $
+# $Id: dbman.py 18728 2012-01-09 18:06:11Z m_d_n $
 
 """
 Provide the management of databases. This includes opening, renaming,
@@ -183,11 +183,10 @@ class DbManager(CLIDbManager):
         Grab ENTER so it does not start editing the cell, but behaves
         like double click instead
         """
-        if not event.state or event.state in (gtk.gdk.MOD2_MASK,):
-            if event.keyval in (_RETURN, _KP_ENTER):
-                if self.connect.get_property('sensitive'):
-                    self.top.response(gtk.RESPONSE_OK)
-                    return True
+        if event.keyval in (_RETURN, _KP_ENTER):
+            if self.connect.get_property('sensitive'):
+                self.top.response(gtk.RESPONSE_OK)
+                return True
         return False
 
     def __selection_changed(self, selection):
@@ -551,7 +550,7 @@ class DbManager(CLIDbManager):
 
         # close the database if the user has requested to delete the
         # active database
-        if self.data_to_delete[OPEN_COL]:
+        if self.data_to_delete[PATH_COL] == self.active:
             self.dbstate.no_database()
             
         store, node = self.selection.get_selected()
