@@ -19,7 +19,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: buttontab.py 16506 2011-01-30 16:43:36Z gburto01 $
+# $Id: buttontab.py 18586 2011-12-12 18:38:43Z m_d_n $
 
 #-------------------------------------------------------------------------
 #
@@ -220,16 +220,13 @@ class ButtonTab(GrampsTab):
                     return
                 self.add_button_clicked(obj)
             elif event.keyval in (_OPEN,) and self.share_btn and \
-                    event.state in (gtk.gdk.CONTROL_MASK, 
-                                    gtk.gdk.CONTROL_MASK | gtk.gdk.MOD2_MASK):
+                    (event.state & gtk.gdk.CONTROL_MASK):
                 self.share_button_clicked(obj)
             elif event.keyval in (_LEFT,) and \
-                    event.state in (gtk.gdk.MOD1_MASK, 
-                                    gtk.gdk.MOD1_MASK | gtk.gdk.MOD2_MASK):
+                    (event.state & gtk.gdk.MOD1_MASK):
                 self.prev_page()
             elif event.keyval in (_RIGHT,) and \
-                    event.state in (gtk.gdk.MOD1_MASK, 
-                                    gtk.gdk.MOD1_MASK | gtk.gdk.MOD2_MASK):
+                    (event.state & gtk.gdk.MOD1_MASK):
                 self.next_page()
             else:
                 return
