@@ -19,7 +19,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: surnametab.py 18101 2011-09-02 20:09:55Z nick-h $
+# $Id: surnametab.py 18586 2011-12-12 18:38:43Z m_d_n $
 
 #-------------------------------------------------------------------------
 #
@@ -323,9 +323,11 @@ class SurnameTab(EmbeddedList):
         """
         if not EmbeddedList.key_pressed(self, obj, event):
             if event.type == gtk.gdk.KEY_PRESS and event.keyval in (_TAB,):
-                if event.state not in (gtk.gdk.SHIFT_MASK, gtk.gdk.CONTROL_MASK):
+                if not (event.state & (gtk.gdk.SHIFT_MASK |
+                                       gtk.gdk.CONTROL_MASK)):
                     return self.next_cell()
-                elif event.state in (gtk.gdk.SHIFT_MASK, gtk.gdk.CONTROL_MASK):
+                elif (event.state & (gtk.gdk.SHIFT_MASK |
+                                     gtk.gdk.CONTROL_MASK)):
                     return self.prev_cell()
                 else:
                     return
