@@ -3,6 +3,7 @@
 #
 # Copyright (C) 2000-2006  Donald N. Allingham
 #               2009       Gary Burton
+#               2011  Michiel D. Nauta
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -19,7 +20,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: editeventref.py 16680 2011-02-20 10:52:06Z bmcage $
+# $Id: editeventref.py 18471 2011-11-21 10:30:31Z romjerome $
 
 #-------------------------------------------------------------------------
 #
@@ -82,6 +83,11 @@ class EditEventRef(EditReference):
         self.primtab = RefTab(self.dbstate, self.uistate, self.track, 
                               _('_General'), tblref)
 
+    def _post_init(self):
+        date = self.top.get_object('eer_date_entry')
+        if not date.get_text_length():
+            date.grab_focus();
+
     def _init_event(self):
         if not self.db.readonly:
             self.commit_event = self.db.commit_personal_event
