@@ -20,7 +20,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: editfamily.py 18084 2011-08-29 19:06:59Z m_d_n $
+# $Id: editfamily.py 18627 2011-12-18 10:07:22Z m_d_n $
 
 #-------------------------------------------------------------------------
 #
@@ -151,11 +151,15 @@ class ChildEmbedList(EmbeddedList):
         return reflist.index(obj)
 
     def _find_row(self, x, y):
-        row = self.tree.get_path_at_pos(x, y)
+        row = self.tree.get_dest_row_at_pos(x, y)
         if row is None:
             return len(self.family.get_child_ref_list())
         else:
-            return row[0][0]
+            if row[1] in (gtk.TREE_VIEW_DROP_BEFORE,
+                          gtk.TREE_VIEW_DROP_INTO_OR_BEFORE):
+                return row[0][0]
+            else:
+                return row[0][0]+1
 
     def _handle_drag(self, row, obj):
         self.family.get_child_ref_list().insert(row, obj)
@@ -169,7 +173,7 @@ class ChildEmbedList(EmbeddedList):
             del dlist[row_from]
         else:
             del dlist[row_from]
-            dlist.insert(row_to-1, obj)
+            dlist.insert(row_to, obj)
         self.changed = True
         self.rebuild()
 
@@ -182,7 +186,10 @@ class ChildEmbedList(EmbeddedList):
                 continue
             name = self._column_names[pair[1]][0]
             render = gtk.CellRendererText()
-            column = gtk.TreeViewColumn(name, render, markup=pair[1])
+            if pair[1] in (6, 7): # date columns
+                column = gtk.TreeViewColumn(name, render, markup=pair[1])
+            else:
+                column = gtk.TreeViewColumn(name, render, text=pair[1])
             column.set_min_width(50)
 
             column.set_resizable(True)
@@ -941,15 +948,13 @@ class EditFamily(EditPrimary):
             if birth:
                 #if event changes it view needs to update
                 self.callman.register_handles({'event': [birth.get_handle()]})
-            if birth and birth.get_type() == gen.lib.EventType.BAPTISM:
-                birth_label.set_label(_("Baptism:"))
+                birth_label.set_label("%s:" % birth.get_type())
 
             death = get_death_or_fallback(db, person)
             if death:
                 #if event changes it view needs to update
                 self.callman.register_handles({'event': [death.get_handle()]})
-            if death and death.get_type() == gen.lib.EventType.BURIAL:
-                death_label.set_label(_("Burial:"))
+                death_label.set_label("%s:" % death.get_type())
 
             btn_edit.set_tooltip_text(_('Edit %s') % name)
             btn_index.hide()
