@@ -4,6 +4,7 @@
 # Copyright (C) 2000-2006  Donald N. Allingham
 #               2008-2009  Stephane Charette <stephanecharette@gmail.com>
 #               2009       Gary Burton
+#               2011       Robert Cheramy <robert@cheramy.net>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -20,7 +21,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: editmediaref.py 16680 2011-02-20 10:52:06Z bmcage $
+# $Id: editmediaref.py 18474 2011-11-21 12:16:41Z romjerome $
 
 #-------------------------------------------------------------------------
 #
@@ -51,7 +52,8 @@ from gen.db import DbTxn
 from glade import Glade
 from displaytabs import (SourceEmbedList, AttrEmbedList, MediaBackRefList, 
                          NoteTab)
-from gui.widgets import MonitoredSpinButton, MonitoredEntry, PrivacyButton
+from gui.widgets import (MonitoredSpinButton, MonitoredEntry, PrivacyButton,
+                         MonitoredDate, MonitoredTagList)
 from editreference import RefTab, EditReference
 from addmedia import AddMediaObject
 
@@ -147,6 +149,7 @@ class EditMediaRef(EditReference):
             self.subpixmap.set_from_pixbuf(pb)
 
     def _setup_fields(self):
+       
         ebox_shared = self.top.get_object('eventbox')
         ebox_shared.connect('button-press-event', self.button_press_event)
 
@@ -249,6 +252,22 @@ class EditMediaRef(EditReference):
             self.source.set_path,
             self.source.get_path,
             self.db.readonly)
+            
+        self.date_field = MonitoredDate(
+            self.top.get_object("date_entry"),
+            self.top.get_object("date_edit"),
+            self.source.get_date_object(),
+            self.uistate, self.track,
+            self.db.readonly)
+            
+        self.tags = MonitoredTagList(
+            self.top.get_object("tag_label"), 
+            self.top.get_object("tag_button"), 
+            self.source.set_tag_list, 
+            self.source.get_tag_list,
+            self.db,
+            self.uistate, self.track,
+            self.db.readonly)
 
     def set_corner1_x(self, value):
         """
@@ -448,12 +467,12 @@ class EditMediaRef(EditReference):
             if new_x2 - new_x1 >= 5 and new_y2 - new_y1 >= 5:
 
                 # get the image size and calculate the X and Y offsets
-                # (image is centered when smaller than const.THUMBSCALE)
+                # (image is centered *horizontally* when smaller than const.THUMBSCALE)
                 pixbuf = self.subpixmap.get_pixbuf();
                 w = pixbuf.get_width()
                 h = pixbuf.get_height()
                 x = (const.THUMBSCALE - w) / 2
-                y = (const.THUMBSCALE - h) / 2
+                y = 0
 
                 # if the click was outside of the image,
                 # bring it within the boundaries
