@@ -3,6 +3,7 @@
 #
 # Copyright (C) 2000-2006  Donald N. Allingham
 #               2009       Gary Burton
+#               2011  Michiel D. Nauta / MathieuMD
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -19,7 +20,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: editsourceref.py 16680 2011-02-20 10:52:06Z bmcage $
+# $Id: editsourceref.py 18471 2011-11-21 10:30:31Z romjerome $
 
 #-------------------------------------------------------------------------
 #
@@ -80,6 +81,14 @@ class EditSourceRef(EditReference):
         self.primtab = RefTab(self.dbstate, self.uistate, self.track, 
                               _('General'), tblref)
 
+    def _post_init(self):
+        title = self.top.get_object('title')
+        volume = self.top.get_object('volume')
+        if not title.get_text_length():
+            title.grab_focus();
+        elif not volume.get_text_length():
+            volume.grab_focus();
+
     def _connect_signals(self):
         self.define_ok_button(self.top.get_object('ok'),self.ok_clicked)
         self.define_cancel_button(self.top.get_object('cancel'))
