@@ -21,7 +21,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: _reportdialog.py 17043 2011-04-05 11:55:09Z ldnp $
+# $Id: _reportdialog.py 18613 2011-12-17 13:57:50Z ldnp $
 
 #-------------------------------------------------------------------------
 #
@@ -51,7 +51,7 @@ import gtk
 from gen.ggettext import gettext as _
 import config
 import Errors
-from gui.utils import ProgressMeter, open_file_with_default_application
+from gui.utils import open_file_with_default_application
 from QuestionDialog import ErrorDialog, OptionDialog
 from gen.plug.report import (CATEGORY_TEXT, CATEGORY_DRAW, CATEGORY_BOOK,
                              CATEGORY_CODE, CATEGORY_WEB, CATEGORY_GRAPHVIZ,
@@ -70,43 +70,6 @@ import Utils
 #-------------------------------------------------------------------------
 URL_REPORT_PAGE = URL_MANUAL_PAGE + "_-_Reports"
 
-#-------------------------------------------------------------------------------
-#
-# Private Functions
-#
-#-------------------------------------------------------------------------------
-def _run_long_process_in_thread(func, header):
-    """
-    This function will spawn a new thread to execute the provided function.
-    While the function is running, a progress bar will be created. 
-    The progress bar will show activity while the function executes.
-    
-    @param func: A function that will take an unknown amount of time to 
-        complete. 
-    @type category: callable
-    @param header: A header for the progress bar.
-        Example: "Updating Data"
-    @type name: string
-    @return: nothing
-    
-    """
-    pbar = ProgressMeter(_('Processing File'))
-    pbar.set_pass(total=40, 
-                  mode=ProgressMeter.MODE_ACTIVITY, 
-                  header=header)
-    
-    sys_thread = threading.Thread(target=func)
-    sys_thread.start()
-    
-    while sys_thread.isAlive():
-        # The loop runs 20 times per second until the thread completes.
-        # With the progress pass total set at 40, it should move across the bar
-        # every two seconds.
-        time.sleep(0.05)
-        pbar.step()   
-    
-    pbar.close()
-
 #-------------------------------------------------------------------------
 #
 # ReportDialog class
@@ -703,7 +666,7 @@ def report(dbstate, uistate, person, report_class, options_class,
                     # bar. So the progress bar should not be used.
                     do_report()
                 else:
-                    _run_long_process_in_thread(do_report, dialog.report_name)
+                    do_report()
 
                     if dialog.open_with_app.get_active():
                         out_file = dialog.options.get_output()
