@@ -20,7 +20,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: listview.py 17084 2011-04-09 14:08:29Z nick-h $
+# $Id: listview.py 18586 2011-12-12 18:38:43Z m_d_n $
 
 """
 Provide the base classes for GRAMPS' DataView classes
@@ -809,10 +809,9 @@ class ListView(NavigationView):
         """
         if not self.dbstate.open:
             return False
-        if not event.state or event.state in (gtk.gdk.MOD2_MASK, ):
-            if event.keyval in (gtk.keysyms.Return, gtk.keysyms.KP_Enter):
-                self.edit(obj)
-                return True
+        if event.keyval in (gtk.keysyms.Return, gtk.keysyms.KP_Enter):
+            self.edit(obj)
+            return True
         return False
 
     def _key_press_tree(self, obj, event):
@@ -823,7 +822,15 @@ class ListView(NavigationView):
         """
         if not self.dbstate.open:
             return False
-        if not event.state or event.state  in (gtk.gdk.MOD2_MASK, ):
+        elif event.state & gtk.gdk.SHIFT_MASK:
+            if event.keyval in (gtk.keysyms.Return, gtk.keysyms.KP_Enter):
+                store, paths = self.selection.get_selected_rows()
+                if paths:
+                    firstsel = paths[0]
+                    firstnode = self.model.on_get_iter(firstsel)
+                    if len(paths) == 1 and firstnode.handle is None:
+                        return self.expand_collapse_tree_branch()
+        else:
             if event.keyval in (gtk.keysyms.Return, gtk.keysyms.KP_Enter):
                 store, paths = self.selection.get_selected_rows()
                 if paths:
@@ -834,14 +841,6 @@ class ListView(NavigationView):
                     else:
                         self.edit(obj)
                         return True
-        elif event.state in (gtk.gdk.SHIFT_MASK, ):
-            if event.keyval in (gtk.keysyms.Return, gtk.keysyms.KP_Enter):
-                store, paths = self.selection.get_selected_rows()
-                if paths:
-                    firstsel = paths[0]
-                    firstnode = self.model.on_get_iter(firstsel)
-                    if len(paths) == 1 and firstnode.handle is None:
-                        return self.expand_collapse_tree_branch()
             
         return False
 
