@@ -19,7 +19,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: navigationview.py 17783 2011-06-14 21:11:39Z bmcage $
+# $Id: navigationview.py 18586 2011-12-12 18:38:43Z m_d_n $
 
 """
 Provide the base classes for GRAMPS' DataView classes
@@ -503,7 +503,7 @@ class NavigationView(PageView):
         if self.active:
             if event.type == gtk.gdk.KEY_PRESS:
                 if (event.keyval == gtk.keysyms.c and 
-                    event.state == gtk.gdk.CONTROL_MASK | gtk.gdk.MOD2_MASK):
+                    (event.state & gtk.gdk.CONTROL_MASK)):
                     self.call_copy()
                     return True
         return super(NavigationView, self).key_press_handler(widget, event)
