@@ -17,7 +17,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  021111307  USA
 #
 
-# $Id: tags.py 17700 2011-06-06 20:20:42Z m_d_n $
+# $Id: tags.py 19453 2012-05-06 13:12:15Z nick-h $
 """
 Provide tagging functionality.
 """
@@ -210,8 +210,8 @@ class Tags(DbGUIElement):
         tag_menu += '<menuitem action="OrganizeTags"/>'
         tag_menu += '<separator/>'
         for tag_name, handle in self.__tag_list:
-            tag_menu += '<menuitem action="TAG_%s"/>' % escape(tag_name)
-            actions.append(('TAG_%s' % tag_name, None, tag_name, None, None,
+            tag_menu += '<menuitem action="TAG_%s"/>' % handle
+            actions.append(('TAG_%s' % handle, None, tag_name, None, None,
                          make_callback(self.tag_selected_rows, handle)))
         
         self.tag_ui = TAG_1 + tag_menu + TAG_2 + tag_menu + TAG_3
