@@ -3,7 +3,7 @@
 #
 # Copyright (C) 2000-2007  Donald N. Allingham
 # Copyright (C) 2009       Gary Burton
-# Copyright (C) 2009       Nick Hall
+# Copyright (C) 2009-2010  Nick Hall
 # Copyright (C) 2009       Benny Malengier
 #
 # This program is free software; you can redistribute it and/or modify
@@ -50,7 +50,6 @@ import gtk
 # GRAMPS modules
 #
 #-------------------------------------------------------------------------
-import config
 from Utils import conv_unicode_tosrtkey_ongtk
 import gui.widgets.progressdialog as progressdlg
 from Lru import LRU
@@ -102,8 +101,9 @@ class Node(object):
         if not self.handle:
             self.handle = handle
         else:
-            raise ValueError, 'attempt to add twice a node to the model'
-        
+            print ('WARNING: Attempt to add handle twice to the node (%s)' %
+                    handle)
+
     def add_child(self, node, nodemap):
         """
         Add a node to the list of children for this node using the id's in
@@ -173,6 +173,17 @@ class NodeMap(object):
     """
     def __init__(self):
         self.id2node = {}
+
+    def destroy(self):
+        """
+        Unset all elements that can prevent garbage collection
+        """
+##        for key, item in self.id2node.iteritems():
+##            item.prev = None
+##            item.next = None
+##            item.parent = None
+##            item.children = []
+        self.id2node.clear()
     
     def add_node(self, node):
         """
@@ -238,7 +249,6 @@ class TreeBaseModel(gtk.GenericTreeModel):
     Creation:
     db      :   the database
     tooltip_column :  column number of tooltip
-    marker_column  :  column number of marker
     search         :  the search that must be shown
     skip           :  values not to show
     scol           :  column on which to sort
@@ -258,7 +268,7 @@ class TreeBaseModel(gtk.GenericTreeModel):
     # LRU cache size
     _CACHE_SIZE = 250
    
-    def __init__(self, db, tooltip_column, marker_column=None,
+    def __init__(self, db, tooltip_column,
                     search=None, skip=set(),
                     scol=0, order=gtk.SORT_ASCENDING, sort_map=None,
                     nrgroups = 1,
@@ -300,19 +310,7 @@ class TreeBaseModel(gtk.GenericTreeModel):
         
         self.lru_data  = LRU(TreeBaseModel._CACHE_SIZE)
 
-        config.connect("preferences.todo-color",
-                          self.__update_todo)
-        config.connect("preferences.custom-marker-color",
-                          self.__update_custom)
-        config.connect("preferences.complete-color",
-                          self.__update_complete)
-
-        self.complete_color = config.get('preferences.complete-color')
-        self.todo_color = config.get('preferences.todo-color')
-        self.custom_color = config.get('preferences.custom-marker-color')
-
         self._tooltip_column = tooltip_column
-        self._marker_column = marker_column
 
         self.__total = 0
         self.__displayed = 0
@@ -323,6 +321,22 @@ class TreeBaseModel(gtk.GenericTreeModel):
         _LOG.debug(self.__class__.__name__ + ' __init__ ' +
                     str(time.clock() - cput) + ' sec')
 
+    def destroy(self):
+        """
+        Unset all elements that prevent garbage collection
+        """
+        self.db = None
+        self.sort_func = None
+        if self.nodemap:
+            self.nodemap.destroy()
+        self.nodemap = None
+        self.rebuild_data = None
+        self._build_data = None
+        self.search = None
+        self.current_filter = None
+        self.clear_cache()
+        self.lru_data = None
+
     def _set_base_data(self):
         """
         This method must be overwritten in the inheriting class, setting 
@@ -344,24 +358,6 @@ class TreeBaseModel(gtk.GenericTreeModel):
         self.fmap = None
         self.hmap = None
 
-    def __update_todo(self, *args):
-        """
-        Update the todo color when the preferences change.
-        """
-        self.todo_color = config.get('preferences.todo-color')
-        
-    def __update_custom(self, *args):
-        """
-        Update the custom color when the preferences change.
-        """
-        self.custom_color = config.get('preferences.custom-marker-color')
-
-    def __update_complete(self, *args):
-        """
-        Update the complete color when the preferences change.
-        """
-        self.complete_color = config.get('preferences.complete-color')
-
     def displayed(self):
         """
         Return the number of rows displayed.
@@ -380,11 +376,11 @@ class TreeBaseModel(gtk.GenericTreeModel):
         """
         return self._tooltip_column
 
-    def marker_column(self):
+    def color_column(self):
         """
-        Return the marker color column.
+        Return the color column.
         """
-        return self._marker_column
+        return None
 
     def clear_cache(self, handle=None):
         """
@@ -592,8 +588,9 @@ class TreeBaseModel(gtk.GenericTreeModel):
         Otherwise, a node should never be added twice!
         """
         if not self.group_can_have_handle:
-            raise ValueError, 'attempt to add twice a node to the model %s' % \
-                                str(parent) + ' ' + str(child) + ' ' + sortkey
+            print ('WARNING: Attempt to add node twice to the model (%s: %s)' 
+                   % (str(parent), str(child)))
+            return
         if handle:
             node.set_handle(handle)
             if not self._in_build:
@@ -669,6 +666,8 @@ class TreeBaseModel(gtk.GenericTreeModel):
         """
         Add a row to the model.
         """
+        if self.get_node(handle) is not None:
+            return # row already exists
         cput = time.clock()
         if not self.search or \
                 (self.search and self.search.match(handle, self.db)):
@@ -772,7 +771,7 @@ class TreeBaseModel(gtk.GenericTreeModel):
         node = self.nodemap.node(nodeid)
         if node.handle is None:
             # Header rows dont get the foreground color set
-            if col == self._marker_column:
+            if col == self.color_column():
                 return None
 
             # Look for header fuction for column and call it
@@ -811,10 +810,8 @@ class TreeBaseModel(gtk.GenericTreeModel):
         node = self.tree[None]
         pathlist = list(path)
         for index in pathlist:
-            if self.__reverse:
-                node = self.nodemap.node(node.children[-index - 1][1])
-            else:
-                node = self.nodemap.node(node.children[index][1])
+            _index = (-index - 1) if self.__reverse else index
+            node = self.nodemap.node(node.children[_index][1])
         return node
         
     def on_get_path(self, node):
@@ -882,10 +879,8 @@ class TreeBaseModel(gtk.GenericTreeModel):
             node = self.tree[None]
         if node.children:
             if len(node.children) > index:
-                if self.__reverse:
-                    return self.nodemap.node(node.children[-index - 1][1])
-                else:
-                    return self.nodemap.node(node.children[index][1])
+                _index = (-index - 1) if self.__reverse else index
+                return self.nodemap.node(node.children[_index][1])
             else:
                 return None
         else:
