@@ -33,12 +33,7 @@ Reports/Graphical Reports/Personal Tree
 # GRAMPS modules
 #
 #------------------------------------------------------------------------ 
-try:
-    from TransUtils import get_addon_translator
-    _ = get_addon_translator(__file__).gettext
-except:
-    import gettext
-    _ = gettext.gettext
+from gen.ggettext import sgettext as _
 
 from Errors import ReportError
 
@@ -1636,7 +1631,7 @@ class DescendTreeOptions(MenuReportOptions):
             [0, _("Do not include a title") ],
             [1, _("Descendant Chart for [selected person(s)]") ],
             ]
-        if self.name != _RPT_NAME:
+        if self.name.split(",")[0] != _RPT_NAME:
             item_list.append(
                 [2, _("Family Chart for [names of chosen family]") ]
                 )
