@@ -19,7 +19,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: drawplugins.gpr.py 16998 2011-03-30 23:19:10Z ander882 $
+# $Id: drawplugins.gpr.py 18418 2011-11-09 12:18:36Z romjerome $
 
 #------------------------------------------------------------------------
 #
@@ -30,7 +30,7 @@
 plg = newplugin()
 plg.id    = 'ancestor_chart,BKI'
 plg.name  = _("Ancestor Tree")
-plg.description =  _("Produces a graphical ancestral tree")
+plg.description =  _("Produces a graphical ancestral tree (Book report)")
 plg.version = '1.0'
 plg.gramps_target_version = '3.3'
 plg.status = STABLE
@@ -90,7 +90,7 @@ plg.report_modes = [REPORT_MODE_GUI, REPORT_MODE_BKI, REPORT_MODE_CLI]
 plg = newplugin()
 plg.id    = 'descend_chart,BKI'
 plg.name  = _("Descendant Tree")
-plg.description =  _("Produces a graphical descendant tree")
+plg.description =  _("Produces a graphical descendant tree (Book report)")
 plg.version = '1.0'
 plg.gramps_target_version = '3.3'
 plg.status = STABLE
@@ -128,7 +128,7 @@ plg.report_modes = [REPORT_MODE_GUI, REPORT_MODE_CLI]
 plg = newplugin()
 plg.id    = 'family_descend_chart,BKI'
 plg.name  = _("Family Descendant Tree")
-plg.description =  _("Produces a graphical descendant tree around a family")
+plg.description =  _("Produces a graphical descendant tree around a family (Book report)")
 plg.version = '1.0'
 plg.status = STABLE
 plg.fname = 'DescendTree.py'
