@@ -22,7 +22,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: ExportPkg.py 17538 2011-05-19 20:38:03Z m_d_n $
+# $Id: ExportPkg.py 18701 2012-01-04 18:42:22Z m_d_n $
 
 "Export to GRAMPS package"
 
@@ -176,7 +176,12 @@ class PackageWriter(object):
             fs_top.destroy()
         #---------------------------------------------------------------
 
-        archive = tarfile.open(self.filename,'w:gz')
+        try:
+            archive = tarfile.open(self.filename,'w:gz')
+        except EnvironmentError, msg:
+            log.warn(str(msg))
+            self.msg_callback(_('Failure writing %s') % self.filename, str(msg))
+            return 0
         
         # Write media files first, since the database may be modified 
         # during the process (i.e. when removing object)
