@@ -19,7 +19,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: libodfbackend.py 16210 2010-11-18 20:19:50Z bmcage $
+# $Id: libodfbackend.py 18404 2011-11-05 17:10:08Z noirauds $
 
 """File and File format management for the openoffice reports
 """
@@ -122,20 +122,17 @@ class OdfBackend(DocBackend):
         if tagtype not in self.SUPPORTED_MARKUP:
             return None
         if ( tagtype == DocBackend.FONTCOLOR ):
-            return ('<text:span text:style-name=\"FontColor__%s__\">' % 
-                                self.ESCAPE_FUNC()(value), 
+            return ('<text:span text:style-name=\"FontColor__%s__\">' % value,
                     '</text:span>')
         elif ( tagtype == DocBackend.FONTFACE ):
-            return ('<text:span text:style-name=\"FontFace__%s__\">' % 
-                                self.ESCAPE_FUNC()(value), 
+            return ('<text:span text:style-name=\"FontFace__%s__\">' %
+                                self.ESCAPE_FUNC()(value),
                     '</text:span>')
         elif ( tagtype == DocBackend.FONTSIZE ):
-            return ('<text:span text:style-name=\"FontSize__%s__\">' % 
-                                self.ESCAPE_FUNC()(value), 
+            return ('<text:span text:style-name=\"FontSize__%d__\">' % value,
                     '</text:span>')
         else: #elif ( tagtype == DocBackend.HIGHLIGHT ):
-            return ('<text:span text:style-name=\"FontHighlight__%s__\">' % 
-                                self.ESCAPE_FUNC()(value), 
+            return ('<text:span text:style-name=\"FontHighlight__%s__\">' % value,
                     '</text:span>')
 
     def format_link(self, value):
