@@ -18,7 +18,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: libtranslate.py 18007 2011-08-08 06:43:41Z romjerome $
+# $Id: libtranslate.py 18843 2012-02-10 15:08:36Z romjerome $
 
 """
 Translator class for use by plugins.
@@ -236,3 +236,11 @@ class Translator:
         :rtype: unicode
         """
         return GrampsType.xml_str(name)
+
+        # List of translated strings used here
+        # Dead code for l10n; added on translation template
+        # Translation string should be same as key name
+        # ex: AttributeType
+        #(FATHER_AGE  , _("Father's Age"), "Father Age"),
+        #(MOTHER_AGE  , _("Mother's Age"), "Mother Age"),
+        _("Father Age"), _("Mother Age")
