@@ -20,7 +20,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: grampsmaps.py 18025 2011-08-11 07:51:17Z noirauds $
+# $Id: grampsmaps.py 18398 2011-11-02 17:08:59Z noirauds $
 
 #-------------------------------------------------------------------------
 #
@@ -56,6 +56,7 @@ import constants
 from gen.ggettext import sgettext as _
 from gen.ggettext import ngettext
 from config import config
+from QuestionDialog import ErrorDialog
 
 #-------------------------------------------------------------------------
 #
@@ -159,10 +160,10 @@ class osmGpsMap():
 
     def build_widget(self):
         self.vbox = gtk.VBox(False, 0)
-        cache_path = os.path.join(const.HOME_DIR, 'maps')
+        cache_path = config.get('geography.path')
         if not os.path.isdir(cache_path):
             try:
-                os.mkdir(cache_path, 0750)
+                os.makedirs(cache_path, 0755) # create dir like mkdir -p
             except:
                 ErrorDialog(_("Can't create tiles cache directory %s") %
                              cache_path )
@@ -177,10 +178,10 @@ class osmGpsMap():
             self.osm.image_remove_all()
             self.vbox.remove(self.osm)
             self.osm.destroy()
-        tiles_path=os.path.join(GEOGRAPHY_PATH, constants.tiles_path[map_type])
+        tiles_path=os.path.join(config.get('geography.path'), constants.tiles_path[map_type])
         if not os.path.isdir(tiles_path):
             try:
-                os.mkdir(tiles_path, 0750)
+                os.makedirs(tiles_path, 0755) # create dir like mkdir -p
             except:
                 ErrorDialog(_("Can't create tiles cache directory for '%s'.") %
                              constants.map_title[map_type])
