@@ -19,7 +19,7 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
-# $Id: BirthdayReport.py 17839 2011-06-27 15:21:40Z m_d_n $
+# $Id: BirthdayReport.py 18259 2011-10-08 11:25:38Z romjerome $
 #
 
 #------------------------------------------------------------------------
@@ -370,6 +370,11 @@ class CalendarOptions(MenuReportOptions):
 
         country = EnumeratedListOption(_("Country for holidays"), 0)
         holiday_table = libholiday.HolidayTable()
+        countries = holiday_table.get_countries()
+        countries.sort()
+        if (len(countries) == 0 or 
+            (len(countries) > 0 and countries[0] != '')):
+            countries.insert(0, '')
         count = 0
         for c in  holiday_table.get_countries():
             country.add_item(count, c)
