@@ -22,7 +22,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: pedigreeview.py 17414 2011-05-05 08:52:47Z romjerome $
+# $Id: pedigreeview.py 18671 2011-12-31 22:03:44Z nick-h $
 
 #-------------------------------------------------------------------------
 #
@@ -726,6 +726,7 @@ class PedigreeView(NavigationView):
                                 'interface.pedview-show-marriage')
         # Tree draw direction
         self.tree_direction = self._config.get('interface.pedview-tree-direction')
+        self.cb_change_scroll_direction(None, self.tree_direction < 2)
         # Show on not unknown people.
         # Default - not show, for mo fast display hight tree
         self.show_unknown_people = self._config.get(
@@ -859,6 +860,19 @@ class PedigreeView(NavigationView):
         except AttributeError, msg:
             RunDatabaseRepair(str(msg))
 
+    def _connect_db_signals(self):
+        """
+        Connect database signals.
+        """
+        self._add_db_signal('person-add', self.person_rebuild)
+        self._add_db_signal('person-update', self.person_rebuild)
+        self._add_db_signal('person-delete', self.person_rebuild)
+        self._add_db_signal('person-rebuild', self.person_rebuild_bm)
+        self._add_db_signal('family-update', self.person_rebuild)
+        self._add_db_signal('family-add', self.person_rebuild)
+        self._add_db_signal('family-delete', self.person_rebuild)
+        self._add_db_signal('family-rebuild', self.person_rebuild)
+        
     def change_db(self, db):
         """
         Callback associated with DbState. Whenever the database
@@ -867,14 +881,7 @@ class PedigreeView(NavigationView):
         is no need to store the database, since we will get the value
         from self.state.db
         """
-        db.connect('person-add', self.person_rebuild)
-        db.connect('person-update', self.person_rebuild)
-        db.connect('person-delete', self.person_rebuild)
-        db.connect('person-rebuild', self.person_rebuild_bm)
-        db.connect('family-update', self.person_rebuild)
-        db.connect('family-add', self.person_rebuild)
-        db.connect('family-delete', self.person_rebuild)
-        db.connect('family-rebuild', self.person_rebuild)
+        self._change_db(db)
         self.bookmarks.update_bookmarks(self.dbstate.db.get_bookmarks())
         if self.active:
             self.bookmarks.redraw()
@@ -1016,6 +1023,11 @@ class PedigreeView(NavigationView):
         lst = [None] * (2**self.force_size)
         self.find_tree(person, 0, 1, lst)
 
+        # Purge current table content
+        for child in self.table.get_children():
+            child.destroy()
+        self.table.resize(1, 1)
+
         if person:
             self.rebuild(self.table, pos, lst, self.force_size)
 
@@ -1027,11 +1039,6 @@ class PedigreeView(NavigationView):
         All display options process in this function.
         """
 
-        # Purge current table content
-        for child in table_widget.get_children():
-            child.destroy()
-        table_widget.resize(1, 1)
-
         # Calculate maximum table size
         xmax = 0
         ymax = 0
