@@ -23,7 +23,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: WebCal.py 18130 2011-09-09 19:09:44Z m_d_n $
+# $Id: WebCal.py 19314 2012-04-13 16:07:20Z romjerome $
 
 """
 Web Calendar generator.
@@ -324,7 +324,7 @@ class WebCalReport(Report):
         Copies all the necessary stylesheets and images for these calendars
         """
         # Copy the screen stylesheet
-        if self.css:
+        if self.css and self.css != 'No style sheet':
             fname = CSS[self.css]["filename"]
             self.copy_file(fname, _CALENDARSCREEN, "styles")
 
@@ -761,7 +761,6 @@ class WebCalReport(Report):
                                         fname_date = '%04d%02d%02d' % (year,month,day) + self.ext
 
                                         # create hyperlink to one_day()
-                                        fname_date = full_month_name + '/' + fname_date 
                                         tcell += Html("a", datediv, href = fname_date, inline = True)
 
                                         # only year_glance() needs this to create the one_day() pages 
@@ -975,7 +974,7 @@ class WebCalReport(Report):
              for each year being created...
         """
 
-        nr_up = 2                    # number of directory levels up to get to root
+        nr_up = 1                    # number of directory levels up to get to root
 
         # get year and month from event_date for use in this section
         year = event_date.get_year()
